==> OpenCL-0.8.3.tgz: OpenCL-0.8.3/src/lookup.cpp <==
/*************************************************
* Algorithm Lookup Source File                   *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/lookup.h>
#include <map>

namespace OpenCL {

namespace {

std::map<std::string, BlockCipher*> bc_map;
std::map<std::string, StreamCipher*> sc_map;
std::map<std::string, HashFunction*> hf_map;
std::map<std::string, MessageAuthenticationCode*> mac_map;

}

/*************************************************
* Retrieve a block cipher                        *
*************************************************/
BlockCipher* get_block_cipher(const std::string& name)
   {
   std::map<std::string, BlockCipher*>::const_iterator algo;
   algo = bc_map.find(name);
   if(algo == bc_map.end())
      throw Algorithm_Not_Found(name);
   return algo->second->clone();
   }

/*************************************************
* Retrieve a stream cipher                       *
*************************************************/
StreamCipher* get_stream_cipher(const std::string& name)
   {
   std::map<std::string, StreamCipher*>::const_iterator algo;
   algo = sc_map.find(name);
   if(algo == sc_map.end())
      throw Algorithm_Not_Found(name);
   return algo->second->clone();
   }

/*************************************************
* Retrieve a hash function                       *
*************************************************/
HashFunction* get_hash(const std::string& name)
   {
   std::map<std::string, HashFunction*>::const_iterator algo;
   algo = hf_map.find(name);
   if(algo == hf_map.end())
      throw Algorithm_Not_Found(name);
   return algo->second->clone();
   }

/*************************************************
* Retrieve a MAC                                 *
*************************************************/
MessageAuthenticationCode* get_mac(const std::string& name)
   {
   std::map<std::string, MessageAuthenticationCode*>::const_iterator algo;
   algo = mac_map.find(name);
   if(algo == mac_map.end())
      throw Algorithm_Not_Found(name);
   return algo->second->clone();
   }

/*************************************************
* Add a block cipher to the lookup table         *
*************************************************/
void add_algorithm(BlockCipher* algo)
   {
   if(algo == 0)
      throw Invalid_Argument("add_algorithm: Invalid pointer");
   if(bc_map.find(algo->name()) != bc_map.end())
      throw Exception("add_algorithm: This algorithm is already loaded");
   bc_map[algo->name()] = algo;
   }

/*************************************************
* Add a stream cipher to the lookup table        *
*************************************************/
void add_algorithm(StreamCipher* algo)
   {
   if(algo == 0)
      throw Invalid_Argument("add_algorithm: Invalid pointer");
   if(sc_map.find(algo->name()) != sc_map.end())
      throw Exception("add_algorithm: This algorithm is already loaded");
   sc_map[algo->name()] = algo;
   }

/*************************************************
* Add a hash function to the lookup table        *
*************************************************/
void add_algorithm(HashFunction* algo)
   {
   if(algo == 0)
      throw Invalid_Argument("add_algorithm: Invalid pointer");
   if(hf_map.find(algo->name()) != hf_map.end())
      throw Exception("add_algorithm: This algorithm is already loaded");
   hf_map[algo->name()] = algo;
   }

/*************************************************
* Add a MAC to the lookup table                  *
*************************************************/
void add_algorithm(MessageAuthenticationCode* algo)
   {
   if(algo == 0)
      throw Invalid_Argument("add_algorithm: Invalid pointer");
   if(mac_map.find(algo->name()) != mac_map.end())
      throw Exception("add_algorithm: This algorithm is already loaded");
   mac_map[algo->name()] = algo;
   }

/*************************************************
* Destroy the lookup tables                      *
*************************************************/
void destroy_lookup_tables()
   {
   std::map<std::string, BlockCipher*>::iterator bc_iter;
   for(bc_iter = bc_map.begin(); bc_iter != bc_map.end(); bc_iter++)
      delete bc_iter->second;

   std::map<std::string, StreamCipher*>::iterator sc_iter;
   for(sc_iter = sc_map.begin(); sc_iter != sc_map.end(); sc_iter++)
      delete sc_iter->second;

   std::map<std::string, HashFunction*>::iterator hf_iter;
   for(hf_iter = hf_map.begin(); hf_iter != hf_map.end(); hf_iter++)
      delete hf_iter->second;

   std::map<std::string, MessageAuthenticationCode*>::iterator mac_iter;
   for(mac_iter = mac_map.begin(); mac_iter != mac_map.end(); mac_iter++)
      delete mac_iter->second;
   }

}

==> OpenCL-0.8.4.tgz: OpenCL-0.8.4/src/lookup.cpp <==
/*************************************************
* Algorithm Lookup Table Source File             *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/lookup.h>
#include <map>

namespace OpenCL {

namespace {

std::map<std::string, BlockCipher*> bc_map;
std::map<std::string, StreamCipher*> sc_map;
std::map<std::string, HashFunction*> hf_map;
std::map<std::string, MessageAuthenticationCode*> mac_map;

}

/*************************************************
* Retrieve a block cipher                        *
*************************************************/
const BlockCipher* retrieve_block_cipher(const std::string& name)
   {
   std::map<std::string, BlockCipher*>::const_iterator algo;
   algo = bc_map.find(name);
   if(algo == bc_map.end())
      return 0;
   return algo->second;
   }

/*************************************************
* Retrieve a stream cipher                       *
*************************************************/
const StreamCipher* retrieve_stream_cipher(const std::string& name)
   {
   std::map<std::string, StreamCipher*>::const_iterator algo;
   algo = sc_map.find(name);
   if(algo == sc_map.end())
      return 0;
   return algo->second;
   }

/*************************************************
* Retrieve a hash function                       *
*************************************************/
const HashFunction* retrieve_hash(const std::string& name)
   {
   std::map<std::string, HashFunction*>::const_iterator algo;
   algo = hf_map.find(name);
   if(algo == hf_map.end())
      return 0;
   return algo->second;
   }

/*************************************************
* Retrieve a MAC                                 *
*************************************************/
const MessageAuthenticationCode* retrieve_mac(const std::string& name)
   {
   std::map<std::string, MessageAuthenticationCode*>::const_iterator algo;
   algo = mac_map.find(name);
   if(algo == mac_map.end())
      return 0;
   return algo->second;
   }

/*************************************************
* Add a block cipher to the lookup table         *
*************************************************/
void add_algorithm(BlockCipher* algo)
   {
   if(algo == 0)
      throw Internal_Error("add_algorithm: Invalid pointer");
   if(bc_map.find(algo->name()) != bc_map.end())
      throw Internal_Error("add_algorithm: This algorithm is already loaded");
   bc_map[algo->name()] = algo;
   }

/*************************************************
* Add a stream cipher to the lookup table        *
*************************************************/
void add_algorithm(StreamCipher* algo)
   {
   if(algo == 0)
      throw Internal_Error("add_algorithm: Invalid pointer");
   if(sc_map.find(algo->name()) != sc_map.end())
      throw Internal_Error("add_algorithm: This algorithm is already loaded");
   sc_map[algo->name()] = algo;
   }

/*************************************************
* Add a hash function to the lookup table        *
*************************************************/
void add_algorithm(HashFunction* algo)
   {
   if(algo == 0)
      throw Internal_Error("add_algorithm: Invalid pointer");
   if(hf_map.find(algo->name()) != hf_map.end())
      throw Internal_Error("add_algorithm: This algorithm is already loaded");
   hf_map[algo->name()] = algo;
   }

/*************************************************
* Add a MAC to the lookup table                  *
*************************************************/
void add_algorithm(MessageAuthenticationCode* algo)
   {
   if(algo == 0)
      throw Internal_Error("add_algorithm: Invalid pointer");
   if(mac_map.find(algo->name()) != mac_map.end())
      throw Internal_Error("add_algorithm: This algorithm is already loaded");
   mac_map[algo->name()] = algo;
   }

/*************************************************
* Destroy the lookup tables                      *
*************************************************/
void destroy_lookup_tables()
   {
   std::map<std::string, BlockCipher*>::iterator bc_iter;
   for(bc_iter = bc_map.begin(); bc_iter != bc_map.end(); bc_iter++)
      delete bc_iter->second;

   std::map<std::string, StreamCipher*>::iterator sc_iter;
   for(sc_iter = sc_map.begin(); sc_iter != sc_map.end(); sc_iter++)
      delete sc_iter->second;

   std::map<std::string, HashFunction*>::iterator hf_iter;
   for(hf_iter = hf_map.begin(); hf_iter != hf_map.end(); hf_iter++)
      delete hf_iter->second;

   std::map<std::string, MessageAuthenticationCode*>::iterator mac_iter;
   for(mac_iter = mac_map.begin(); mac_iter != mac_map.end(); mac_iter++)
      delete mac_iter->second;

   bc_map.clear();
   sc_map.clear();
   hf_map.clear();
   mac_map.clear();
   }

}
